#!/usr/bin/env python
import os
from glob import glob
for f in glob("*"):
    if os.path.isdir(f):
        os.chdir(f)
        if os.path.isdir("cpp"):
            os.chdir("cpp")
            if os.path.exists("Makefile"):
                os.system("make clean")
            os.chdir("..")
        if os.path.isdir("python"):
            os.chdir("python")
            if os.path.exists("Makefile"):
                os.system("make clean")
            os.chdir("..")

        os.chdir("..")
